@@ -58,11 +58,11 @@ struct ExternalFaces
   class NumExternalFacesPerStructuredCell : public vtkm::worklet::WorkletMapPointToCell
   {
   public:
-    typedef void ControlSignature(CellSetIn inCellSet,
+    using ControlSignature = void(CellSetIn inCellSet,
                                   FieldOut<> numFacesInCell,
                                   FieldInPoint<Vec3> pointCoordinates);
-    typedef _2 ExecutionSignature(CellShape, _3);
-    typedef _1 InputDomain;
+    using ExecutionSignature = _2(CellShape, _3);
+    using InputDomain = _1;
 
     VTKM_CONT
     NumExternalFacesPerStructuredCell(const vtkm::Vec<vtkm::Float64, 3>& min_point,
@@ -130,39 +130,29 @@ struct ExternalFaces
   class BuildConnectivityStructured : public vtkm::worklet::WorkletMapPointToCell
   {
   public:
-    typedef void ControlSignature(CellSetIn inCellSet,
+    using ControlSignature = void(CellSetIn inCellSet,
                                   WholeCellSetIn<> inputCell,
                                   FieldOut<> faceShapes,
                                   FieldOut<> facePointCount,
                                   FieldOut<> faceConnectivity,
                                   FieldInPoint<Vec3> pointCoordinates);
-    typedef void ExecutionSignature(CellShape, VisitIndex, InputIndex, _2, _3, _4, _5, _6);
-    typedef _1 InputDomain;
+    using ExecutionSignature = void(CellShape, VisitIndex, InputIndex, _2, _3, _4, _5, _6);
+    using InputDomain = _1;
 
     using ScatterType = vtkm::worklet::ScatterCounting;
 
-    VTKM_CONT
-    ScatterType GetScatter() const { return this->Scatter; }
-
     template <typename CountArrayType, typename Device>
-    VTKM_CONT BuildConnectivityStructured(const vtkm::Vec<vtkm::Float64, 3>& min_point,
-                                          const vtkm::Vec<vtkm::Float64, 3>& max_point,
-                                          const CountArrayType& countArray,
-                                          Device)
-      : MinPoint(min_point)
-      , MaxPoint(max_point)
-      , Scatter(countArray, Device())
+    VTKM_CONT static ScatterType MakeScatter(const CountArrayType& countArray, Device)
     {
       VTKM_IS_ARRAY_HANDLE(CountArrayType);
+      return ScatterType(countArray, Device());
     }
 
     VTKM_CONT
     BuildConnectivityStructured(const vtkm::Vec<vtkm::Float64, 3>& min_point,
-                                const vtkm::Vec<vtkm::Float64, 3>& max_point,
-                                const ScatterType& scatter)
+                                const vtkm::Vec<vtkm::Float64, 3>& max_point)
       : MinPoint(min_point)
       , MaxPoint(max_point)
-      , Scatter(scatter)
     {
     }
 
@@ -306,9 +296,8 @@ struct ExternalFaces
 
       vtkm::IdComponent faceIndex = FindFaceIndexForVisit(visitIndex, pointCoordinates);
 
-      vtkm::VecCConst<vtkm::IdComponent> localFaceIndices =
-        vtkm::exec::CellFaceLocalIndices(faceIndex, shape, *this);
-      vtkm::IdComponent numFacePoints = localFaceIndices.GetNumberOfComponents();
+      const vtkm::IdComponent numFacePoints =
+        vtkm::exec::CellFaceNumberOfPoints(faceIndex, shape, *this);
       VTKM_ASSERT(numFacePoints == faceConnectivity.GetNumberOfComponents());
 
       typename CellSetType::IndicesType inCellIndices = cellSet.GetIndices(inputIndex);
@@ -318,23 +307,23 @@ struct ExternalFaces
 
       for (vtkm::IdComponent facePointIndex = 0; facePointIndex < numFacePoints; facePointIndex++)
       {
-        faceConnectivity[facePointIndex] = inCellIndices[localFaceIndices[facePointIndex]];
+        faceConnectivity[facePointIndex] =
+          inCellIndices[vtkm::exec::CellFaceLocalIndex(facePointIndex, faceIndex, shape, *this)];
       }
     }
 
   private:
     vtkm::Vec<vtkm::Float64, 3> MinPoint;
     vtkm::Vec<vtkm::Float64, 3> MaxPoint;
-    ScatterType Scatter;
   };
 
   //Worklet that returns the number of faces for each cell/shape
   class NumFacesPerCell : public vtkm::worklet::WorkletMapPointToCell
   {
   public:
-    typedef void ControlSignature(CellSetIn inCellSet, FieldOut<> numFacesInCell);
-    typedef _2 ExecutionSignature(CellShape);
-    typedef _1 InputDomain;
+    using ControlSignature = void(CellSetIn inCellSet, FieldOut<> numFacesInCell);
+    using ExecutionSignature = _2(CellShape);
+    using InputDomain = _1;
 
     template <typename CellShapeTag>
     VTKM_EXEC vtkm::IdComponent operator()(CellShapeTag shape) const
@@ -347,31 +336,15 @@ struct ExternalFaces
   class FaceHash : public vtkm::worklet::WorkletMapPointToCell
   {
   public:
-    typedef void ControlSignature(CellSetIn cellset,
+    using ControlSignature = void(CellSetIn cellset,
                                   FieldOut<> faceHashes,
                                   FieldOut<> originCells,
                                   FieldOut<> originFaces);
-    typedef void ExecutionSignature(_2, _3, _4, CellShape, FromIndices, InputIndex, VisitIndex);
-    typedef _1 InputDomain;
+    using ExecutionSignature = void(_2, _3, _4, CellShape, FromIndices, InputIndex, VisitIndex);
+    using InputDomain = _1;
 
     using ScatterType = vtkm::worklet::ScatterCounting;
 
-    VTKM_CONT
-    ScatterType GetScatter() const { return this->Scatter; }
-
-    template <typename CountArrayType, typename Device>
-    VTKM_CONT FaceHash(const CountArrayType& countArray, Device)
-      : Scatter(countArray, Device())
-    {
-      VTKM_IS_ARRAY_HANDLE(CountArrayType);
-    }
-
-    VTKM_CONT
-    FaceHash(const ScatterType& scatter)
-      : Scatter(scatter)
-    {
-    }
-
     template <typename CellShapeTag, typename CellNodeVecType>
     VTKM_EXEC void operator()(vtkm::HashType& faceHash,
                               vtkm::Id& cellIndex,
@@ -386,9 +359,6 @@ struct ExternalFaces
       cellIndex = inputIndex;
       faceIndex = visitIndex;
     }
-
-  private:
-    ScatterType Scatter;
   };
 
   // Worklet that identifies the number of cells written out per face.
@@ -398,12 +368,12 @@ struct ExternalFaces
   class FaceCounts : public vtkm::worklet::WorkletReduceByKey
   {
   public:
-    typedef void ControlSignature(KeysIn keys,
+    using ControlSignature = void(KeysIn keys,
                                   WholeCellSetIn<> inputCells,
                                   ValuesIn<> originCells,
                                   ValuesIn<> originFaces,
                                   ReducedValuesOut<> numOutputCells);
-    typedef _5 ExecutionSignature(_2, _3, _4);
+    using ExecutionSignature = _5(_2, _3, _4);
     using InputDomain = _1;
 
     template <typename CellSetType, typename OriginCellsType, typename OriginFacesType>
@@ -515,30 +485,21 @@ public:
   class NumPointsPerFace : public vtkm::worklet::WorkletReduceByKey
   {
   public:
-    typedef void ControlSignature(KeysIn keys,
+    using ControlSignature = void(KeysIn keys,
                                   WholeCellSetIn<> inputCells,
                                   ValuesIn<> originCells,
                                   ValuesIn<> originFaces,
                                   ReducedValuesOut<> numPointsInFace);
-    typedef _5 ExecutionSignature(_2, _3, _4, VisitIndex);
+    using ExecutionSignature = _5(_2, _3, _4, VisitIndex);
     using InputDomain = _1;
 
     using ScatterType = vtkm::worklet::ScatterCounting;
 
-    VTKM_CONT
-    ScatterType GetScatter() const { return this->Scatter; }
-
     template <typename CountArrayType, typename Device>
-    VTKM_CONT NumPointsPerFace(const CountArrayType& countArray, Device)
-      : Scatter(countArray, Device())
+    VTKM_CONT static ScatterType MakeScatter(const CountArrayType& countArray, Device)
     {
       VTKM_IS_ARRAY_HANDLE(CountArrayType);
-    }
-
-    VTKM_CONT
-    NumPointsPerFace(const ScatterType& scatter)
-      : Scatter(scatter)
-    {
+      return ScatterType(countArray, Device());
     }
 
     template <typename CellSetType, typename OriginCellsType, typename OriginFacesType>
@@ -553,43 +514,24 @@ public:
       return vtkm::exec::CellFaceNumberOfPoints(
         originFaces[myIndex], cellSet.GetCellShape(originCells[myIndex]), *this);
     }
-
-  private:
-    ScatterType Scatter;
   };
 
   // Worklet that returns the shape and connectivity for each external face
   class BuildConnectivity : public vtkm::worklet::WorkletReduceByKey
   {
   public:
-    typedef void ControlSignature(KeysIn keys,
+    using ControlSignature = void(KeysIn keys,
                                   WholeCellSetIn<> inputCells,
                                   ValuesIn<> originCells,
                                   ValuesIn<> originFaces,
                                   ReducedValuesOut<> shapesOut,
                                   ReducedValuesOut<> connectivityOut,
                                   ReducedValuesOut<> cellIdMapOut);
-    typedef void ExecutionSignature(_2, _3, _4, VisitIndex, _5, _6, _7);
+    using ExecutionSignature = void(_2, _3, _4, VisitIndex, _5, _6, _7);
     using InputDomain = _1;
 
     using ScatterType = vtkm::worklet::ScatterCounting;
 
-    VTKM_CONT
-    ScatterType GetScatter() const { return this->Scatter; }
-
-    template <typename CountArrayType, typename Device>
-    VTKM_CONT BuildConnectivity(const CountArrayType& countArray, Device)
-      : Scatter(countArray, Device())
-    {
-      VTKM_IS_ARRAY_HANDLE(CountArrayType);
-    }
-
-    VTKM_CONT
-    BuildConnectivity(const ScatterType& scatter)
-      : Scatter(scatter)
-    {
-    }
-
     template <typename CellSetType,
               typename OriginCellsType,
               typename OriginFacesType,
@@ -602,36 +544,36 @@ public:
                               ConnectivityType& connectivityOut,
                               vtkm::Id& cellIdMapOut) const
     {
-      vtkm::IdComponent myIndex =
+      const vtkm::IdComponent myIndex =
         ExternalFaces::FindUniqueFace(cellSet, originCells, originFaces, visitIndex, this);
+      const vtkm::IdComponent myFace = originFaces[myIndex];
+
 
       typename CellSetType::CellShapeTag shapeIn = cellSet.GetCellShape(originCells[myIndex]);
-      shapeOut = vtkm::exec::CellFaceShape(originFaces[myIndex], shapeIn, *this);
+      shapeOut = vtkm::exec::CellFaceShape(myFace, shapeIn, *this);
       cellIdMapOut = originCells[myIndex];
 
-      vtkm::VecCConst<vtkm::IdComponent> localFaceIndices =
-        vtkm::exec::CellFaceLocalIndices(originFaces[myIndex], shapeIn, *this);
-      vtkm::IdComponent numFacePoints = localFaceIndices.GetNumberOfComponents();
+      const vtkm::IdComponent numFacePoints =
+        vtkm::exec::CellFaceNumberOfPoints(myFace, shapeIn, *this);
+
       VTKM_ASSERT(numFacePoints == connectivityOut.GetNumberOfComponents());
 
       typename CellSetType::IndicesType inCellIndices = cellSet.GetIndices(originCells[myIndex]);
 
       for (vtkm::IdComponent facePointIndex = 0; facePointIndex < numFacePoints; facePointIndex++)
       {
-        connectivityOut[facePointIndex] = inCellIndices[localFaceIndices[facePointIndex]];
+        connectivityOut[facePointIndex] =
+          inCellIndices[vtkm::exec::CellFaceLocalIndex(facePointIndex, myFace, shapeIn, *this)];
       }
     }
-
-  private:
-    ScatterType Scatter;
   };
 
   class IsPolyDataCell : public vtkm::worklet::WorkletMapPointToCell
   {
   public:
-    typedef void ControlSignature(CellSetIn inCellSet, FieldOut<> isPolyDataCell);
-    typedef _2 ExecutionSignature(CellShape);
-    typedef _1 InputDomain;
+    using ControlSignature = void(CellSetIn inCellSet, FieldOut<> isPolyDataCell);
+    using ExecutionSignature = _2(CellShape);
+    using InputDomain = _1;
 
     template <typename CellShapeTag>
     VTKM_EXEC vtkm::IdComponent operator()(CellShapeTag shape) const
@@ -645,29 +587,11 @@ public:
   public:
     using ScatterType = vtkm::worklet::ScatterCounting;
 
-    VTKM_CONT
-    ScatterType GetScatter() const { return this->Scatter; }
-
-    template <typename CountArrayType, typename Device>
-    VTKM_CONT CountPolyDataCellPoints(const CountArrayType& countArray, Device)
-      : Scatter(countArray, Device())
-    {
-      VTKM_IS_ARRAY_HANDLE(CountArrayType);
-    }
-
-    VTKM_CONT
-    CountPolyDataCellPoints(const ScatterType& scatter)
-      : Scatter(scatter)
-    {
-    }
-
-    typedef void ControlSignature(CellSetIn inCellSet, FieldOut<> numPoints);
-    typedef _2 ExecutionSignature(PointCount);
-    typedef _1 InputDomain;
+    using ControlSignature = void(CellSetIn inCellSet, FieldOut<> numPoints);
+    using ExecutionSignature = _2(PointCount);
+    using InputDomain = _1;
 
     VTKM_EXEC vtkm::Id operator()(vtkm::Id count) const { return count; }
-  private:
-    ScatterType Scatter;
   };
 
   class PassPolyDataCells : public vtkm::worklet::WorkletMapPointToCell
@@ -675,27 +599,11 @@ public:
   public:
     using ScatterType = vtkm::worklet::ScatterCounting;
 
-    VTKM_CONT
-    ScatterType GetScatter() const { return this->Scatter; }
-
-    template <typename CountArrayType, typename Device>
-    VTKM_CONT PassPolyDataCells(const CountArrayType& countArray, Device)
-      : Scatter(countArray, Device())
-    {
-      VTKM_IS_ARRAY_HANDLE(CountArrayType);
-    }
-
-    VTKM_CONT
-    PassPolyDataCells(const ScatterType& scatter)
-      : Scatter(scatter)
-    {
-    }
-
-    typedef void ControlSignature(CellSetIn inputTopology,
+    using ControlSignature = void(CellSetIn inputTopology,
                                   FieldOut<> shapes,
                                   FieldOut<> pointIndices,
                                   FieldOut<> cellIdMapOut);
-    typedef void ExecutionSignature(CellShape, PointIndices, InputIndex, _2, _3, _4);
+    using ExecutionSignature = void(CellShape, PointIndices, InputIndex, _2, _3, _4);
 
     template <typename CellShape, typename InPointIndexType, typename OutPointIndexType>
     VTKM_EXEC void operator()(const CellShape& inShape,
@@ -715,9 +623,6 @@ public:
         outPoints[pointIndex] = inPoints[pointIndex];
       }
     }
-
-  private:
-    ScatterType Scatter;
   };
 
   template <typename T>
@@ -789,23 +694,17 @@ public:
   {
     vtkm::Vec<vtkm::Float64, 3> MinPoint;
     vtkm::Vec<vtkm::Float64, 3> MaxPoint;
-    vtkm::exec::ConnectivityStructured<vtkm::TopologyElementTagPoint,
-                                       vtkm::TopologyElementTagCell,
-                                       3>
-      Conn;
 
-    Conn = inCellSet.PrepareForInput(
-      DeviceAdapter(), vtkm::TopologyElementTagPoint(), vtkm::TopologyElementTagCell());
+    vtkm::Id3 PointDimensions = inCellSet.GetPointDimensions();
 
-    vtkm::Id3 PointDimensions = Conn.GetPointDimensions();
-    typedef vtkm::cont::ArrayHandle<vtkm::FloatDefault> DefaultHandle;
-    typedef vtkm::cont::ArrayHandleCartesianProduct<DefaultHandle, DefaultHandle, DefaultHandle>
-      CartesianArrayHandle;
+    using DefaultHandle = vtkm::cont::ArrayHandle<vtkm::FloatDefault>;
+    using CartesianArrayHandle =
+      vtkm::cont::ArrayHandleCartesianProduct<DefaultHandle, DefaultHandle, DefaultHandle>;
 
-    if (coord.GetData().IsSameType(CartesianArrayHandle()))
+    auto coordData = coord.GetData();
+    if (coordData.IsType<CartesianArrayHandle>())
     {
-      CartesianArrayHandle vertices;
-      vertices = coord.GetData().Cast<CartesianArrayHandle>();
+      auto vertices = coordData.Cast<CartesianArrayHandle>();
 
       MinPoint[0] =
         static_cast<vtkm::Float64>(vertices.GetPortalConstControl().GetFirstPortal().Get(0));
@@ -823,12 +722,8 @@ public:
     }
     else
     {
-      vtkm::cont::ArrayHandleUniformPointCoordinates vertices;
-      vertices = coord.GetData().Cast<vtkm::cont::ArrayHandleUniformPointCoordinates>();
-      typedef typename vtkm::cont::ArrayHandleUniformPointCoordinates UniformArrayHandle;
-      typedef
-        typename UniformArrayHandle::ExecutionTypes<DeviceAdapter>::PortalConst UniformConstPortal;
-      UniformConstPortal Coordinates = vertices.PrepareForInput(DeviceAdapter());
+      auto vertices = coordData.Cast<vtkm::cont::ArrayHandleUniformPointCoordinates>();
+      auto Coordinates = vertices.GetPortalConstControl();
 
       MinPoint = Coordinates.GetOrigin();
       vtkm::Vec<vtkm::Float64, 3> spacing = Coordinates.GetSpacing();
@@ -844,13 +739,15 @@ public:
     vtkm::cont::ArrayHandle<vtkm::IdComponent> numExternalFaces;
     vtkm::worklet::DispatcherMapTopology<NumExternalFacesPerStructuredCell>
       numExternalFacesDispatcher((NumExternalFacesPerStructuredCell(MinPoint, MaxPoint)));
+    numExternalFacesDispatcher.SetDevice(DeviceAdapter());
 
-    numExternalFacesDispatcher.Invoke(inCellSet, numExternalFaces, coord.GetData());
+    numExternalFacesDispatcher.Invoke(inCellSet, numExternalFaces, coordData);
 
-    typedef typename vtkm::cont::DeviceAdapterAlgorithm<DeviceAdapter> DeviceAlgorithms;
+    using DeviceAlgorithms = typename vtkm::cont::DeviceAdapterAlgorithm<DeviceAdapter>;
     vtkm::Id numberOfExternalFaces = DeviceAlgorithms::Reduce(numExternalFaces, 0, vtkm::Sum());
 
-    vtkm::worklet::ScatterCounting scatterCellToExternalFace(numExternalFaces, DeviceAdapter());
+    auto scatterCellToExternalFace =
+      BuildConnectivityStructured::MakeScatter(numExternalFaces, DeviceAdapter());
 
     // Maps output cells to input cells. Store this for cell field mapping.
     this->CellIdMap = scatterCellToExternalFace.GetOutputToInputMap();
@@ -866,8 +763,9 @@ public:
     faceConnectivity.Allocate(connectivitySize);
 
     vtkm::worklet::DispatcherMapTopology<BuildConnectivityStructured>
-      buildConnectivityStructuredDispatcher(
-        (BuildConnectivityStructured(MinPoint, MaxPoint, scatterCellToExternalFace)));
+      buildConnectivityStructuredDispatcher(BuildConnectivityStructured(MinPoint, MaxPoint),
+                                            scatterCellToExternalFace);
+    buildConnectivityStructuredDispatcher.SetDevice(DeviceAdapter());
 
     buildConnectivityStructuredDispatcher.Invoke(
       inCellSet,
@@ -875,7 +773,7 @@ public:
       faceShapes,
       facePointCount,
       vtkm::cont::make_ArrayHandleGroupVec<4>(faceConnectivity),
-      coord.GetData());
+      coordData);
     outCellSet.Fill(inCellSet.GetNumberOfPoints(), faceShapes, facePointCount, faceConnectivity);
   }
 
@@ -902,6 +800,7 @@ public:
     //Create a worklet to map the number of faces to each cell
     vtkm::cont::ArrayHandle<vtkm::IdComponent> facesPerCell;
     vtkm::worklet::DispatcherMapTopology<NumFacesPerCell> numFacesDispatcher;
+    numFacesDispatcher.SetDevice(DeviceAdapter());
 
     numFacesDispatcher.Invoke(inCellSet, facesPerCell);
 
@@ -918,6 +817,7 @@ public:
     {
       vtkm::cont::ArrayHandle<vtkm::IdComponent> isPolyDataCell;
       vtkm::worklet::DispatcherMapTopology<IsPolyDataCell> isPolyDataCellDispatcher;
+      isPolyDataCellDispatcher.SetDevice(DeviceAdapter());
 
       isPolyDataCellDispatcher.Invoke(inCellSet, isPolyDataCell);
 
@@ -927,16 +827,18 @@ public:
 
       if (scatterPolyDataCells.GetOutputRange(inCellSet.GetNumberOfCells()) != 0)
       {
-        vtkm::worklet::DispatcherMapTopology<CountPolyDataCellPoints, DeviceAdapter>
-          countPolyDataCellPointsDispatcher((CountPolyDataCellPoints(scatterPolyDataCells)));
+        vtkm::worklet::DispatcherMapTopology<CountPolyDataCellPoints>
+          countPolyDataCellPointsDispatcher(scatterPolyDataCells);
+        countPolyDataCellPointsDispatcher.SetDevice(DeviceAdapter());
 
         countPolyDataCellPointsDispatcher.Invoke(inCellSet, polyDataPointCount);
 
         vtkm::cont::ConvertNumComponentsToOffsets(
           polyDataPointCount, polyDataOffsets, polyDataConnectivitySize);
 
-        vtkm::worklet::DispatcherMapTopology<PassPolyDataCells, DeviceAdapter>
-          passPolyDataCellsDispatcher((PassPolyDataCells(scatterPolyDataCells)));
+        vtkm::worklet::DispatcherMapTopology<PassPolyDataCells> passPolyDataCellsDispatcher(
+          scatterPolyDataCells);
+        passPolyDataCellsDispatcher.SetDevice(DeviceAdapter());
 
         polyDataConnectivity.Allocate(polyDataConnectivitySize);
 
@@ -973,23 +875,25 @@ public:
     vtkm::cont::ArrayHandle<vtkm::HashType> faceHashes;
     vtkm::cont::ArrayHandle<vtkm::Id> originCells;
     vtkm::cont::ArrayHandle<vtkm::IdComponent> originFaces;
-    vtkm::worklet::DispatcherMapTopology<FaceHash, DeviceAdapter> faceHashDispatcher(
-      (FaceHash(scatterCellToFace)));
+    vtkm::worklet::DispatcherMapTopology<FaceHash> faceHashDispatcher(scatterCellToFace);
+    faceHashDispatcher.SetDevice(DeviceAdapter());
 
     faceHashDispatcher.Invoke(inCellSet, faceHashes, originCells, originFaces);
 
     vtkm::worklet::Keys<vtkm::HashType> faceKeys(faceHashes, DeviceAdapter());
 
     vtkm::cont::ArrayHandle<vtkm::IdComponent> faceOutputCount;
-    vtkm::worklet::DispatcherReduceByKey<FaceCounts, DeviceAdapter> faceCountDispatcher;
+    vtkm::worklet::DispatcherReduceByKey<FaceCounts> faceCountDispatcher;
+    faceCountDispatcher.SetDevice(DeviceAdapter());
 
     faceCountDispatcher.Invoke(faceKeys, inCellSet, originCells, originFaces, faceOutputCount);
 
-    vtkm::worklet::ScatterCounting scatterCullInternalFaces(faceOutputCount, DeviceAdapter());
+    auto scatterCullInternalFaces = NumPointsPerFace::MakeScatter(faceOutputCount, DeviceAdapter());
 
     PointCountArrayType facePointCount;
-    vtkm::worklet::DispatcherReduceByKey<NumPointsPerFace, DeviceAdapter> pointsPerFaceDispatcher(
+    vtkm::worklet::DispatcherReduceByKey<NumPointsPerFace> pointsPerFaceDispatcher(
       scatterCullInternalFaces);
+    pointsPerFaceDispatcher.SetDevice(DeviceAdapter());
 
     pointsPerFaceDispatcher.Invoke(faceKeys, inCellSet, originCells, originFaces, facePointCount);
 
@@ -1004,8 +908,9 @@ public:
     // information to.
     faceConnectivity.Allocate(connectivitySize);
 
-    vtkm::worklet::DispatcherReduceByKey<BuildConnectivity, DeviceAdapter>
-      buildConnectivityDispatcher(scatterCullInternalFaces);
+    vtkm::worklet::DispatcherReduceByKey<BuildConnectivity> buildConnectivityDispatcher(
+      scatterCullInternalFaces);
+    buildConnectivityDispatcher.SetDevice(DeviceAdapter());
 
     vtkm::cont::ArrayHandle<vtkm::Id> faceToCellIdMap;
 
@@ -1027,7 +932,7 @@ public:
     else
     {
       // Join poly data to face data output
-      typedef typename vtkm::cont::DeviceAdapterAlgorithm<DeviceAdapter> DeviceAlgorithm;
+      using DeviceAlgorithm = typename vtkm::cont::DeviceAdapterAlgorithm<DeviceAdapter>;
 
       vtkm::cont::ArrayHandleConcatenate<ShapeArrayType, ShapeArrayType> faceShapesArray(
         faceShapes, polyDataShapes);
@@ -1045,8 +950,8 @@ public:
       DeviceAlgorithm::Copy(connectivityArray, joinedConnectivity);
 
       // Adjust poly data offsets array with face connectivity size before join
-      typedef vtkm::cont::ArrayHandleTransform<OffsetsArrayType, BiasFunctor<vtkm::Id>>
-        TransformBiasArrayType;
+      using TransformBiasArrayType =
+        vtkm::cont::ArrayHandleTransform<OffsetsArrayType, BiasFunctor<vtkm::Id>>;
       TransformBiasArrayType adjustedPolyDataOffsets =
         vtkm::cont::make_ArrayHandleTransform<OffsetsArrayType>(
           polyDataOffsets, BiasFunctor<vtkm::Id>(faceConnectivity.GetNumberOfValues()));
