@@ -19,25 +19,21 @@ public class vtkHyperTree extends vtkObject
   public void Initialize()
     { Initialize_2(); }
 
-  private native long NewCursor_3();
-  public vtkHyperTreeCursor NewCursor() {
-    long temp = NewCursor_3();
+  private native int GetNumberOfLevels_3();
+  public int GetNumberOfLevels()
+    { return GetNumberOfLevels_3(); }
 
-    if (temp == 0) return null;
-    return (vtkHyperTreeCursor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-}
-
-  private native int GetNumberOfLeaves_4();
-  public int GetNumberOfLeaves()
-    { return GetNumberOfLeaves_4(); }
+  private native int GetNumberOfVertices_4();
+  public int GetNumberOfVertices()
+    { return GetNumberOfVertices_4(); }
 
   private native int GetNumberOfNodes_5();
   public int GetNumberOfNodes()
     { return GetNumberOfNodes_5(); }
 
-  private native int GetNumberOfIndex_6();
-  public int GetNumberOfIndex()
-    { return GetNumberOfIndex_6(); }
+  private native int GetNumberOfLeaves_6();
+  public int GetNumberOfLeaves()
+    { return GetNumberOfLeaves_6(); }
 
   private native int GetBranchFactor_7();
   public int GetBranchFactor()
@@ -47,49 +43,57 @@ public class vtkHyperTree extends vtkObject
   public int GetDimension()
     { return GetDimension_8(); }
 
-  private native void SetScale_9(double id0[]);
+  private native int GetNumberOfChildren_9();
+  public int GetNumberOfChildren()
+    { return GetNumberOfChildren_9(); }
+
+  private native void SetScale_10(double id0[]);
   public void SetScale(double id0[])
-    { SetScale_9(id0); }
+    { SetScale_10(id0); }
 
-  private native void GetScale_10(double id0[]);
+  private native void GetScale_11(double id0[]);
   public void GetScale(double id0[])
-    { GetScale_10(id0); }
+    { GetScale_11(id0); }
 
-  private native double GetScale_11(int id0);
+  private native double GetScale_12(int id0);
   public double GetScale(int id0)
-    { return GetScale_11(id0); }
+    { return GetScale_12(id0); }
 
-  private native int GetNumberOfLevels_12();
-  public int GetNumberOfLevels()
-    { return GetNumberOfLevels_12(); }
-
-  private native void SubdivideLeaf_13(vtkHyperTreeCursor id0);
-  public void SubdivideLeaf(vtkHyperTreeCursor id0)
-    { SubdivideLeaf_13(id0); }
-
-  private native int GetActualMemorySize_14();
-  public int GetActualMemorySize()
-    { return GetActualMemorySize_14(); }
-
-  private native long CreateInstance_15(int id0,int id1);
+  private native long CreateInstance_13(int id0,int id1);
   public vtkHyperTree CreateInstance(int id0,int id1) {
-    long temp = CreateInstance_15(id0,id1);
+    long temp = CreateInstance_13(id0,id1);
 
     if (temp == 0) return null;
     return (vtkHyperTree)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
 }
 
-  private native void SetGlobalIndexStart_16(int id0);
+  private native long NewCursor_14();
+  public vtkHyperTreeCursor NewCursor() {
+    long temp = NewCursor_14();
+
+    if (temp == 0) return null;
+    return (vtkHyperTreeCursor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
+}
+
+  private native void SubdivideLeaf_15(vtkHyperTreeCursor id0);
+  public void SubdivideLeaf(vtkHyperTreeCursor id0)
+    { SubdivideLeaf_15(id0); }
+
+  private native int GetActualMemorySize_16();
+  public int GetActualMemorySize()
+    { return GetActualMemorySize_16(); }
+
+  private native void SetGlobalIndexStart_17(int id0);
   public void SetGlobalIndexStart(int id0)
-    { SetGlobalIndexStart_16(id0); }
+    { SetGlobalIndexStart_17(id0); }
 
-  private native void SetGlobalIndexFromLocal_17(int id0,int id1);
+  private native void SetGlobalIndexFromLocal_18(int id0,int id1);
   public void SetGlobalIndexFromLocal(int id0,int id1)
-    { SetGlobalIndexFromLocal_17(id0,id1); }
+    { SetGlobalIndexFromLocal_18(id0,id1); }
 
-  private native int GetGlobalIndexFromLocal_18(int id0);
+  private native int GetGlobalIndexFromLocal_19(int id0);
   public int GetGlobalIndexFromLocal(int id0)
-    { return GetGlobalIndexFromLocal_18(id0); }
+    { return GetGlobalIndexFromLocal_19(id0); }
 
   public vtkHyperTree() { super(); }
 
