@@ -16,8 +16,7 @@ import java.io.File;
  */
 public enum vtkNativeLibrary {
 
-    VTKACCELERATORSDAX("vtkAcceleratorsDaxJava", false),
-    VTKACCELERATORSPISTON("vtkAcceleratorsPistonJava", false),
+    VTKACCELERATORSVTKM("vtkAcceleratorsVTKmJava", false),
     VTKCHARTSCORE("vtkChartsCoreJava", true),
     VTKCOMMONCOLOR("vtkCommonColorJava", true),
     VTKCOMMONCOMPUTATIONALGEOMETRY("vtkCommonComputationalGeometryJava", true),
@@ -31,6 +30,7 @@ public enum vtkNativeLibrary {
     VTKDOMAINSCHEMISTRY("vtkDomainsChemistryJava", true),
     VTKDOMAINSCHEMISTRYOPENGL2("vtkDomainsChemistryOpenGL2Java", true),
     VTKDOMAINSMICROSCOPY("vtkDomainsMicroscopyJava", false),
+    VTKDOMAINSPARALLELCHEMISTRY("vtkDomainsParallelChemistryJava", true),
     VTKFILTERSAMR("vtkFiltersAMRJava", true),
     VTKFILTERSCORE("vtkFiltersCoreJava", true),
     VTKFILTERSEXTRACTION("vtkFiltersExtractionJava", true),
@@ -42,6 +42,7 @@ public enum vtkNativeLibrary {
     VTKFILTERSHYPERTREE("vtkFiltersHyperTreeJava", true),
     VTKFILTERSIMAGING("vtkFiltersImagingJava", true),
     VTKFILTERSMODELING("vtkFiltersModelingJava", true),
+    VTKFILTERSOPENTURNS("vtkFiltersOpenTurnsJava", false),
     VTKFILTERSPARALLEL("vtkFiltersParallelJava", true),
     VTKFILTERSPARALLELDIY2("vtkFiltersParallelDIY2Java", true),
     VTKFILTERSPARALLELFLOWPATHS("vtkFiltersParallelFlowPathsJava", true),
@@ -49,6 +50,7 @@ public enum vtkNativeLibrary {
     VTKFILTERSPARALLELIMAGING("vtkFiltersParallelImagingJava", true),
     VTKFILTERSPARALLELMPI("vtkFiltersParallelMPIJava", true),
     VTKFILTERSPARALLELSTATISTICS("vtkFiltersParallelStatisticsJava", true),
+    VTKFILTERSPARALLELVERDICT("vtkFiltersParallelVerdictJava", true),
     VTKFILTERSPOINTS("vtkFiltersPointsJava", true),
     VTKFILTERSPROGRAMMABLE("vtkFiltersProgrammableJava", true),
     VTKFILTERSPYTHON("vtkFiltersPythonJava", true),
@@ -57,18 +59,21 @@ public enum vtkNativeLibrary {
     VTKFILTERSSELECTION("vtkFiltersSelectionJava", true),
     VTKFILTERSSOURCES("vtkFiltersSourcesJava", true),
     VTKFILTERSSTATISTICS("vtkFiltersStatisticsJava", true),
-    VTKFILTERSSTATISTICSGNUR("vtkFiltersStatisticsGnuRJava", false),
     VTKFILTERSTEXTURE("vtkFiltersTextureJava", true),
+    VTKFILTERSTOPOLOGY("vtkFiltersTopologyJava", true),
     VTKFILTERSVERDICT("vtkFiltersVerdictJava", true),
     VTKGEOVISCORE("vtkGeovisCoreJava", true),
+    VTKGEOVISGDAL("vtkGeovisGDALJava", true),
     VTKIOADIOS("vtkIOADIOSJava", false),
     VTKIOAMR("vtkIOAMRJava", true),
+    VTKIOASYNCHRONOUS("vtkIOAsynchronousJava", true),
+    VTKIOCITYGML("vtkIOCityGMLJava", true),
     VTKIOCORE("vtkIOCoreJava", true),
     VTKIOENSIGHT("vtkIOEnSightJava", true),
     VTKIOEXODUS("vtkIOExodusJava", true),
     VTKIOEXPORT("vtkIOExportJava", true),
-    VTKIOEXPORTOPENGL("vtkIOExportOpenGLJava", false),
-    VTKIOEXPORTOPENGL2("vtkIOExportOpenGL2Java", false),
+    VTKIOEXPORTOPENGL2("vtkIOExportOpenGL2Java", true),
+    VTKIOEXPORTPDF("vtkIOExportPDFJava", true),
     VTKIOFFMPEG("vtkIOFFMPEGJava", true),
     VTKIOGDAL("vtkIOGDALJava", true),
     VTKIOGEOJSON("vtkIOGeoJSONJava", true),
@@ -76,25 +81,32 @@ public enum vtkNativeLibrary {
     VTKIOIMAGE("vtkIOImageJava", true),
     VTKIOIMPORT("vtkIOImportJava", true),
     VTKIOINFOVIS("vtkIOInfovisJava", true),
+    VTKIOLAS("vtkIOLASJava", false),
     VTKIOLSDYNA("vtkIOLSDynaJava", true),
     VTKIOLEGACY("vtkIOLegacyJava", true),
     VTKIOMINC("vtkIOMINCJava", true),
     VTKIOMPIIMAGE("vtkIOMPIImageJava", true),
     VTKIOMPIPARALLEL("vtkIOMPIParallelJava", true),
+    VTKIOMOTIONFX("vtkIOMotionFXJava", true),
     VTKIOMOVIE("vtkIOMovieJava", true),
     VTKIOMYSQL("vtkIOMySQLJava", true),
     VTKIONETCDF("vtkIONetCDFJava", true),
     VTKIOODBC("vtkIOODBCJava", true),
+    VTKIOPDAL("vtkIOPDALJava", true),
     VTKIOPLY("vtkIOPLYJava", true),
     VTKIOPARALLEL("vtkIOParallelJava", true),
     VTKIOPARALLELEXODUS("vtkIOParallelExodusJava", true),
     VTKIOPARALLELLSDYNA("vtkIOParallelLSDynaJava", true),
     VTKIOPARALLELNETCDF("vtkIOParallelNetCDFJava", true),
     VTKIOPARALLELXML("vtkIOParallelXMLJava", true),
+    VTKIOPARALLELXDMF3("vtkIOParallelXdmf3Java", true),
     VTKIOPOSTGRESQL("vtkIOPostgreSQLJava", true),
     VTKIOSQL("vtkIOSQLJava", true),
+    VTKIOSEGY("vtkIOSegYJava", true),
+    VTKIOTRUCHAS("vtkIOTRUCHASJava", true),
     VTKIOTECPLOTTABLE("vtkIOTecplotTableJava", true),
     VTKIOVPIC("vtkIOVPICJava", true),
+    VTKIOVERAOUT("vtkIOVeraOutJava", true),
     VTKIOVIDEO("vtkIOVideoJava", true),
     VTKIOXML("vtkIOXMLJava", true),
     VTKIOXMLPARSER("vtkIOXMLParserJava", true),
@@ -114,7 +126,6 @@ public enum vtkNativeLibrary {
     VTKINFOVISBOOSTGRAPHALGORITHMS("vtkInfovisBoostGraphAlgorithmsJava", true),
     VTKINFOVISCORE("vtkInfovisCoreJava", true),
     VTKINFOVISLAYOUT("vtkInfovisLayoutJava", true),
-    VTKINFOVISPARALLEL("vtkInfovisParallelJava", false),
     VTKINTERACTIONIMAGE("vtkInteractionImageJava", true),
     VTKINTERACTIONSTYLE("vtkInteractionStyleJava", true),
     VTKINTERACTIONWIDGETS("vtkInteractionWidgetsJava", true),
@@ -123,34 +134,29 @@ public enum vtkNativeLibrary {
     VTKPARALLELMPI4PY("vtkParallelMPI4PyJava", true),
     VTKRENDERINGANNOTATION("vtkRenderingAnnotationJava", true),
     VTKRENDERINGCONTEXT2D("vtkRenderingContext2DJava", true),
-    VTKRENDERINGCONTEXTOPENGL("vtkRenderingContextOpenGLJava", false),
     VTKRENDERINGCONTEXTOPENGL2("vtkRenderingContextOpenGL2Java", true),
     VTKRENDERINGCORE("vtkRenderingCoreJava", true),
     VTKRENDERINGEXTERNAL("vtkRenderingExternalJava", false),
     VTKRENDERINGFREETYPE("vtkRenderingFreeTypeJava", true),
-    VTKRENDERINGGL2PS("vtkRenderingGL2PSJava", false),
     VTKRENDERINGGL2PSOPENGL2("vtkRenderingGL2PSOpenGL2Java", true),
     VTKRENDERINGIMAGE("vtkRenderingImageJava", true),
-    VTKRENDERINGLIC("vtkRenderingLICJava", false),
     VTKRENDERINGLICOPENGL2("vtkRenderingLICOpenGL2Java", true),
     VTKRENDERINGLOD("vtkRenderingLODJava", true),
     VTKRENDERINGLABEL("vtkRenderingLabelJava", true),
     VTKRENDERINGMATPLOTLIB("vtkRenderingMatplotlibJava", true),
     VTKRENDERINGOSPRAY("vtkRenderingOSPRayJava", false),
-    VTKRENDERINGOCULUS("vtkRenderingOculusJava", false),
-    VTKRENDERINGOPENGL("vtkRenderingOpenGLJava", false),
     VTKRENDERINGOPENGL2("vtkRenderingOpenGL2Java", true),
     VTKRENDERINGOPENVR("vtkRenderingOpenVRJava", false),
+    VTKRENDERINGOPTIX("vtkRenderingOptiXJava", false),
     VTKRENDERINGPARALLEL("vtkRenderingParallelJava", true),
     VTKRENDERINGPARALLELLIC("vtkRenderingParallelLICJava", true),
+    VTKPYTHONCONTEXT2D("vtkPythonContext2DJava", true),
     VTKRENDERINGQT("vtkRenderingQtJava", true),
     VTKRENDERINGSCENEGRAPH("vtkRenderingSceneGraphJava", true),
     VTKRENDERINGVOLUME("vtkRenderingVolumeJava", true),
     VTKRENDERINGVOLUMEAMR("vtkRenderingVolumeAMRJava", true),
-    VTKRENDERINGVOLUMEOPENGL("vtkRenderingVolumeOpenGLJava", false),
     VTKRENDERINGVOLUMEOPENGL2("vtkRenderingVolumeOpenGL2Java", true),
     VTKTESTINGRENDERING("vtkTestingRenderingJava", true),
-    VTKPYTHONINTERPRETER("vtkPythonInterpreterJava", true),
     VTKVIEWSCONTEXT2D("vtkViewsContext2DJava", true),
     VTKVIEWSCORE("vtkViewsCoreJava", true),
     VTKVIEWSGEOVIS("vtkViewsGeovisJava", true),
